<?xml version='1.0' encoding='iso-8859-1'?>
<xsl:stylesheet version="1.0"
		xmlns:xsl="http://www.w3.org/1999/XSL/Transform"
		xmlns:xt="http://www.jclark.com/xt"
		extension-element-prefixes="xt">
  
  
  <xsl:include href="../version.xsl"/>
  <xsl:include href="../lib/lib.xsl"/>
  <xsl:include href="../common/i18n.xsl"/>
  <xsl:include href="../common/common.xsl"/>
  <xsl:include href="config.xsl"/>
  <xsl:include href="locators.xsl"/>
  <xsl:include href="maketoc.xsl"/>
  <xsl:include href="maketoc-split.xsl"/>
  <xsl:include href="cesHeader.xsl"/>
  <xsl:include href="text.xsl"/>
  <xsl:include href="div.xsl"/>
  <xsl:include href="paragraphs.xsl"/>
  <xsl:include href="seq.xsl"/>
  <xsl:include href="token.xsl"/>
  
  
  <!-- ==================================================================== -->
  
  
  <xsl:template match="*" mode="debug">
    <font color="red">
      <xsl:text>&lt;</xsl:text>
      <xsl:value-of select="name(.)"/>
      <xsl:text>&gt;</xsl:text>
      <xsl:apply-templates/>
      <xsl:text>&lt;/</xsl:text>
      <xsl:value-of select="name(.)"/>
      <xsl:text>&gt;</xsl:text>
    </font>
  </xsl:template>
  
  
  <xsl:template match="text()">
    <xsl:value-of select="."/> 
  </xsl:template>
  
  
  <!-- ======================== -->
  <!-- It is starting from here -->
  <!-- ======================== -->

  
  <xsl:template match="/">
    <xsl:choose>
      <xsl:when test="$output.split.level=-1">
	<xsl:apply-templates select="cesDoc"/>
      </xsl:when>
      <xsl:otherwise>
	<xsl:apply-templates select="cesDoc" mode="output.split"/>
      </xsl:otherwise>
    </xsl:choose>
  </xsl:template>
  
  
  <xsl:template match="cesDoc">
    <xsl:message>CESDOC HTML in normal mode</xsl:message>
    <xsl:call-template name="main.output"/>
  </xsl:template>
  
  
  <xsl:template match="cesDoc" mode="output.split">
    <xsl:message>CESDOC HTML in splitting mode</xsl:message>
    <xt:document method="html" href="{concat($output.index.file,$output.html.extension)}">
      <xsl:call-template name="main.output"/>
    </xt:document>
  </xsl:template>
    
  
  <xsl:template match="cesHeader">
    <xsl:message> => cesHeader</xsl:message>
    <xsl:if test="$output.header">
      <xt:document method="html" href="{concat($output.header.file,$output.html.extension)}">
	<xsl:call-template name="ces.header.output"/>
      </xt:document>
    </xsl:if>
  </xsl:template>
  
  
  <xsl:template match="text">
    <xsl:apply-templates/>
  </xsl:template>
  

  <xsl:template name="cesdoc.title">
    <xsl:variable name="filedesc.title" select="/cesDoc/cesHeader/fileDesc/titleStmt/h.title[1]"/>
    <xsl:choose>
      <xsl:when test="$filedesc.title">
	<xsl:value-of select="$filedesc.title"/>
      </xsl:when>
      <xsl:otherwise>[Untitled document]</xsl:otherwise>
    </xsl:choose>
  </xsl:template>
  
  
  <xsl:template name="html.head.output">
    <xsl:param name="html.head.title"><xsl:text>[Untitled document]</xsl:text></xsl:param>
    <head>
      <title><xsl:value-of select="$html.head.title"/></title>
      <xsl:if test="$html.stylesheet">
      <link rel="stylesheet"
	    href="{$html.stylesheet}"
	    type="{$html.stylesheet.type}"/>
    </xsl:if>
      <meta name="generator" content="XSL Stylesheets for XML CESDOC V{$stylesheet.version} (by {$stylesheet.author})"/>
    </head>
  </xsl:template>
  
  
  <xsl:template name="main.output">
    <xsl:param name="cesdoc.title"><xsl:call-template name="cesdoc.title"/></xsl:param>
    <xsl:message terminate="no">[main.output] => <xsl:value-of select="name()"/></xsl:message>
    <html> 
      <xsl:call-template name="html.head.output">
	<xsl:with-param name="html.head.title" select="$cesdoc.title"/>
      </xsl:call-template>
      <body>
	<xsl:attribute name="bgcolor"><xsl:value-of select="$html.body.bgcolor"/></xsl:attribute>
	<center><h1><xsl:value-of select="$cesdoc.title"/></h1></center>
	<xsl:call-template name="main.toc"/>
	<xsl:apply-templates select="cesHeader"/>
	<xsl:apply-templates select="text"/>
      </body>
    </html> 
  </xsl:template>
  
  
  <xsl:template name="main.toc">
    <xsl:message terminate="no">[main.toc] => <xsl:value-of select="name()"/></xsl:message>
    <h2><xsl:call-template name="i18n.text">
	<xsl:with-param name="text.name">content</xsl:with-param>
      </xsl:call-template></h2>
    <xsl:apply-templates select="cesHeader" mode="main.toc"/>
    <xsl:apply-templates select="text" mode="main.toc"/>
  </xsl:template>
  
  
  <xsl:template match="text" mode="main.toc">
    <xsl:apply-templates select="*" mode="main.toc"/>
  </xsl:template>
  
  
  <xsl:template match="group" mode="main.toc">
    <xsl:for-each select="body">
      <hr/>
      <xsl:apply-templates select="*" mode="main.toc"/>
    </xsl:for-each>
  </xsl:template>
  
  
  <xsl:template match="body" mode="main.toc">
    <xsl:choose>
      <xsl:when test="$output.split.level=-1">
	<xsl:message terminate="no">body [main.toc]</xsl:message>
	<xsl:call-template name="maketoc.div"/>
      </xsl:when>
      <xsl:otherwise>
	<xsl:call-template name="maketoc.div.split"/>
      </xsl:otherwise>
    </xsl:choose>
    <!-- xsl:call-template name="maketoc.div"/ -->
  </xsl:template>
  
  
  <!-- TODO -->
  
  <xsl:template match="cesHeader" mode="main.toc">
    <xsl:param name="elt.name"><xsl:value-of select="name()"/></xsl:param>
    <xsl:variable name="nodes" select="fileDesc | encodingDesc | profileDesc | revisionDesc"/>
    <xsl:if test="$nodes">
      <div class="header.toc">
	<dl>
	  <dt><b><xsl:call-template name="i18n.text">
		<xsl:with-param name="text.name"><xsl:value-of select="$elt.name"/></xsl:with-param>
	      </xsl:call-template></b></dt>
	  <dd>
	    <dl>
	      <xsl:apply-templates select="$nodes" mode="main.toc"/>
	    </dl>
	  </dd>
	</dl>
      </div> 
    </xsl:if>
  </xsl:template>
  
  
  <xsl:template match="fileDesc" mode="main.toc">
    <xsl:message>fileDesc [main.toc]</xsl:message>
    
    <xsl:call-template name="cesheader.entry.toc"/>
  </xsl:template>
  
  
  <xsl:template match="encodingDesc" mode="main.toc">
    <xsl:message>encodingDesc [main.toc]</xsl:message>
    
    <xsl:call-template name="cesheader.entry.toc"/>
  </xsl:template>


  <xsl:template match="profileDesc" mode="main.toc">
    <xsl:message>profileDesc [main.toc]</xsl:message>
    
    <xsl:call-template name="cesheader.entry.toc"/>
  </xsl:template>
  

  <xsl:template match="revisionDesc" mode="main.toc">
    <xsl:message>revisionDesc [main.toc]</xsl:message>
    
    <xsl:call-template name="cesheader.entry.toc"/>
  </xsl:template>
  

  <xsl:template name="cesheader.entry.toc">
    <xsl:param name="elt.id"><xsl:call-template name="element.id"/></xsl:param>
    <xsl:param name="elt.name"><xsl:value-of select="name()"/></xsl:param>
    <xsl:variable name="file.name" select="concat($output.header.file, $output.html.extension)"/>
    
    <dt>
      <b><a><xsl:attribute name="href">
	  <xsl:value-of select="$file.name"/>
	  <xsl:text>#</xsl:text>
	  <xsl:value-of select="$elt.id"/>
	</xsl:attribute>
	<xsl:call-template name="i18n.text">
	  <xsl:with-param name="text.name"><xsl:value-of select="$elt.name"/></xsl:with-param>
	</xsl:call-template>
      </a></b>
    </dt>
    
  </xsl:template>

</xsl:stylesheet>

<!-- Keep this comment at the end of the file
Local variables:
mode: xml
sgml-always-quote-attributes:t
sgml-indent-step:2
sgml-indent-data:t
sgml-default-dtd-file:"/local/led/share/dtd/xsl/xsl.ced"
End:
-->
