<?xml version='1.0' encoding='iso-8859-1'?>
<xsl:stylesheet version="1.0"
		xmlns:xsl="http://www.w3.org/1999/XSL/Transform"
                xmlns:xt="http://www.jclark.com/xt"
                extension-element-prefixes="xt">
  
  
  <xsl:template name="div.root">
    <xsl:variable name="div.id"><xsl:call-template name="element.id"/></xsl:variable>
    <xsl:variable name="div.depth"><xsl:call-template name="div.depth"/></xsl:variable>
    <xsl:message>div.root = <xsl:value-of select="$div.depth"/></xsl:message>
    
    <xsl:call-template name="div.output">
      <xsl:with-param name="div.depth" select="$div.depth"/>
      <xsl:with-param name="div.id" select="$div.id"/>
    </xsl:call-template>
    
  </xsl:template>
  
  
  <xsl:template name="div.root.split">
    <xsl:variable name="div.id"><xsl:call-template name="element.id"/></xsl:variable>
    <xsl:variable name="div.depth"><xsl:call-template name="div.depth"/></xsl:variable>
    <xsl:message>div.root.split depth=<xsl:value-of select="$div.depth"/> id=<xsl:value-of select="$div.id"/></xsl:message>
    <xsl:choose>
      <xsl:when test="$div.depth &lt; $output.split.level">
	<xt:document method="html" href="{concat($div.id, $output.html.extension)}">
	  <xsl:call-template name="div.output.split">
	    <xsl:with-param name="div.depth" select="$div.depth"/>
	    <xsl:with-param name="div.id" select="$div.id"/>
	  </xsl:call-template>
	</xt:document>
      </xsl:when>
      <xsl:otherwise>
	<xsl:comment>Depth <xsl:value-of select="$div.depth"/>, not more splitting</xsl:comment>
	<xsl:call-template name="div.output">
	  <xsl:with-param name="div.depth" select="$div.depth"/>
	  <xsl:with-param name="div.id" select="$div.id"/>
	</xsl:call-template>
      </xsl:otherwise>
    </xsl:choose>
  </xsl:template>
  
  <xsl:template name="div.output.split">
    <xsl:param name="div.depth">0</xsl:param>
    <xsl:variable name="div.id"><xsl:call-template name="element.id"/></xsl:variable>
    <html>
      <xsl:call-template name="html.head.output">
	<xsl:with-param name="html.head.title" select="head//text()"/>
      </xsl:call-template>
      <body>
	<xsl:attribute name="bgcolor"><xsl:value-of select="$html.body.bgcolor"/></xsl:attribute>
	<xsl:element name="h{$div.depth + 1}">
	  <a name="{$div.id}"></a>
	  <xsl:call-template name="i18n.text.type"/><xsl:call-template name="nbsp"/>
	  <xsl:call-template name="div.header"/>
        </xsl:element>
	<xsl:call-template name="div.toc"/>
	<div class="div">
	  <xsl:apply-templates select="*" mode="output.split"/>
        </div>
      </body>
    </html>
  </xsl:template>
  
  <xsl:template name="div.output">
    <xsl:param name="div.depth">0</xsl:param>
    <xsl:param name="div.id" select="generate-id(.)"/>
    <div class="div">
      <xsl:element name="h{$div.depth + 1}">
        <a name="{$div.id}"></a>
        <xsl:call-template name="i18n.text.type"/><xsl:call-template name="nbsp"/>
        <xsl:call-template name="div.header"/>
      </xsl:element>
      <xsl:apply-templates select="*"/>
    </div>
  </xsl:template>
  
  <xsl:template name="div.toc">
    <xsl:variable name="div.id"><xsl:call-template name="element.id"/></xsl:variable>
    <xsl:if test="child::div">
      <hr noshade="noshade"/>
      <div class="div.toc">
	<ul>
	  <xsl:for-each select="div">
	    <xsl:variable name="div.child.id"><xsl:call-template name="element.id"/></xsl:variable>
	    <li><xsl:call-template name="i18n.text.type"/><xsl:call-template name="nbsp"/>
	      <a class="subtoc" href="{concat($div.child.id,$output.html.extension)}">
	        <xsl:call-template name="div.header"/></a>
	    </li>
          </xsl:for-each>
        </ul>
	<hr noshade="noshade"/>
      </div>
    </xsl:if>
  </xsl:template>
  
  
  <xsl:template name="div.header">
    <xsl:number level="multiple" count="div"/>
    <xsl:text>. </xsl:text>
    <xsl:apply-templates select="head" mode="div.header"/>
  </xsl:template>
  
  
  <!-- div content : 
  bibl, byline, caption, div, figure, head, list, note, opener, p, poem, quote, sp, table
  -->
  
  <xsl:template match="div">

    <xsl:variable name="div.id"><xsl:call-template name="element.id"/></xsl:variable>
    <xsl:variable name="div.depth"><xsl:call-template name="div.depth"/></xsl:variable>
    
    <xsl:message terminate="no">[div] depth=<xsl:value-of select="$div.depth"/> id=<xsl:value-of select="$div.id"/></xsl:message>
    
	<xsl:call-template name="div.output">
	  <xsl:with-param name="div.depth" select="$div.depth"/>
	  <xsl:with-param name="div.id" select="$div.id"/>
	</xsl:call-template>
    
  </xsl:template>
  
  
  <xsl:template match="div" mode="output.split">
    <xsl:variable name="div.id"><xsl:call-template name="element.id"/></xsl:variable>
    <xsl:variable name="div.depth"><xsl:call-template name="div.depth"/></xsl:variable>
    <xsl:message terminate="no">(output.split) div.inner=<xsl:value-of select="$div.depth"/> id=<xsl:value-of select="$div.id"/></xsl:message>
    
    <xsl:choose>
      <xsl:when test="$div.depth &lt; $output.split.level">
	<xt:document method="html" href="{concat($div.id,$output.html.extension)}">
	  <xsl:call-template name="div.output.split">
	    <xsl:with-param name="div.id" select="$div.id"/>
	    <xsl:with-param name="div.depth" select="$div.depth"/>
	  </xsl:call-template>
	  
	</xt:document>
      </xsl:when>
      <xsl:otherwise>
	<xsl:comment>Depth <xsl:value-of select="$div.depth"/>, not more splitting (inner)</xsl:comment>
	<xsl:call-template name="div.output">
	  <xsl:with-param name="div.depth" select="$div.depth"/>
	  <xsl:with-param name="div.id" select="$div.id"/>
	</xsl:call-template>
	
      </xsl:otherwise>
    </xsl:choose>
    
  </xsl:template>
  
  
  <xsl:template match="head" mode="div.header">
    <xsl:if test="preceding-sibling::head">
      <xsl:text> - </xsl:text>
    </xsl:if>
    <xsl:apply-templates/>
  </xsl:template>
  
  
  <xsl:template match="head"><xsl:apply-templates select="*"/></xsl:template>
  
  
  <xsl:template match="head" mode="output.split"><xsl:apply-templates select="*"/></xsl:template>
  
  
</xsl:stylesheet>

<!-- Keep this comment at the end of the file
Local variables:
mode: xml
sgml-always-quote-attributes:t
sgml-indent-step:2
sgml-indent-data:t
sgml-default-dtd-file:"/local/led/share/dtd/xsl/xsl.ced"
End:
-->
